<?php

class actionFeedbacklIndex extends cmsAction {

    public function run() {

        if (!$this->isEnabled()) {

            cmsCore::error404();
        }

        $sess_id = $this->request->get('s', null);

        if (isset($sess_id)) {

            if (cmsUser::isSessionSet('feedbackl' . $sess_id)) {

                $items = cmsUser::SessionGet('feedbackl' . $sess_id, true);

                if (isset($items['file'])) {

                    $file = $this->parsefile($items['file']);
                }
                return $this->cms_template->render('feedbackl_ok', array(
                            'items' => $items,
                            'file' => isset($file) ? $file : '',
                ));
            } else {

                $this->redirectTo('feedbackl');  // или можно  cmsCore::error404();
            }
        } else {

            $user = cmsUser::getInstance();

            $errors = false;

            $is_captcha_valid = true;

            $form = $this->getForm('feedbackl');

            $fieldset_id = $form->getLastFieldsetId();

            $is_submitted = $this->request->has('submit');

            $items = array(
                'user_id' => 0,
                'name' => '',
                'email' => '',
                'title' => '',
                'message' => ''
            );
            if ($this->options['editor'] == '0') {

                $form->addField($fieldset_id, new fieldText('message', array(
                    'title' => LANG_FEEDBACKL_MESSAGE,
                    'hint' => LANG_FEEDBACKL_HINT_MESSAGE,
                    'rules' => array(
                        array('required'),
                ))));
            } else {

                $form->addField($fieldset_id, new fieldHtml('message', array(
                    'title' => LANG_FEEDBACKL_MESSAGE,
                    'hint' => LANG_FEEDBACKL_HINT_MESSAGE,
                    'options' => array(
                        'editor' => $this->options['editor']),
                    'rules' => array(
                        array('required'),
                ))));
            }
            if ($user->id) {

                $items = array(
                    'email' => $user->email,
                    'name' => $user->nickname
                );
            }
            if (isset($this->options['files'])) {

                $form->addField($fieldset_id, new fieldFile('file', array(
                    'title' => LANG_FEEDBACKL_FILE,
                    'hint' => LANG_FEEDBACKL_FILE_HINT,
                    'options' => array(
                        'extensions' => $this->options['extensions'],
                        'max_size_mb' => $this->options['max_size_mb'],
                        'show_size' => $this->options['show_size'],
                        'show_name' => $this->options['show_name'],
                    )
                )));
            }

            $form->addField($fieldset_id, new fieldCheckbox('chek', array(
                'title' =>"<a class='ajaxlink ajax-modal' href='".href_to('feedbackl', 'text')."'>".$this->options['chek_url_title']."</a>",
                'rules' => array(
                    array('required'),
            ))));
            if ($is_submitted) {

                $items = array_merge($items, $form->parse($this->request, $is_submitted));

                if (!$user->id) {

                    $is_captcha_valid = cmsEventsManager::hook('captcha_validate', $this->request);

                    if (!$is_captcha_valid) {

                        $errors = true;

                        cmsUser::addSessionMessage(LANG_CAPTCHA_ERROR, 'error');
                    }
                }
                // проверяем допустимость e-mail, имени и IP
                //
                if ($this->options['check_bl_controll']) {

                    foreach ($this->options['check_bl_controll'] as $param) {

                        switch ($param) {

                            case 0: if (!$this->cms_core->getController('auth')->isNameAllowed($items['name'])) {
                                    $errors['name'] = sprintf(LANG_AUTH_RESTRICTED_NAME, $items['name']);
                                }
                            case 1: if (!$this->cms_core->getController('auth')->isEmailAllowed($items['email'])) {
                                    $errors['email'] = sprintf(LANG_AUTH_RESTRICTED_EMAIL, $items['email']);
                                }

                            case 2: if (!$this->cms_core->getController('auth')->isIPAllowed(cmsUser::get('ip'))) {
                                    cmsUser::addSessionMessage(sprintf(LANG_AUTH_RESTRICTED_IP, cmsUser::get('ip')), 'error');
                                    $errors = true;
                                }
                        }
                    }
                }

                if (!$errors) {

                    $errors = $form->validate($this, $items);
                }

                if (!$errors) {
                    $items['date'] = date('Y-m-d H:i:s');

                    if ($user->id) {

                        $items['user_id'] = $user->id;

                        $items['user_name'] = '<a href="' . href_to_abs('users', $user->id) . '">' . $user->nickname . '</a>';
                    } else {

                        $items['user_name'] = LANG_FEEDBACKL_GUEST;
                    }
                    // добавляем в базу
                    $feedback_id = $this->model->addFeedBack($items);

                    $model = cmsCore::getModel('moderation');

                    $moderator_id = $model->getNextModeratorId('feedbackl');

                    $users_model = cmsCore::getModel('users');

                    $moderator = $users_model->getUser($moderator_id);
                    // отправляеим на почту
                    if ($this->options['moder_in'] == 0) {

                        $to = array('email' => $moderator['email'], 'name' => $moderator['nickname']);
                        if ($this->options['mes'] == true) {

                            $messages_controller = cmsCore::getController('messages', $this->request);

                            if ($user->is_admin) {

                                $title = ': <a href="' . href_to('admin/controllers/edit/feedbackl/', 'view', $feedback_id) . '">' . $items['title'] . '</a><br/>';
                            } else {

                                $title = ': ' . $items['title'] . '<br/>';
                            }

                            $messages = LANG_FEEDBACKL_HI . ' ' . $to['name'] . '!<br/>'
                                    . LANG_FEEDBACKL_SIT . ' "' . $this->cms_config->sitename . '" ' . LANG_FEEDBACKL_HINT . '<br/>'
                                    . LANG_FEEDBACKL_USER . ': ' . $items['user_name'] . '<br/>'
                                    . LANG_FEEDBACKL_TO . ': ' . $items['name'] . '<br/>'
                                    . LANG_FEEDBACKL_E_MAIL . ': ' . $items['email'] . '<br/>'
                                    . LANG_FEEDBACKL_TITLE . $title
                                    . LANG_FEEDBACKL_TEXT . ': ' . $items['message'] . '<br/>'
                                    . LANG_DATE . ': ' . $items['date'] . '<br/>'
                                    . LANG_FEEDBACKL_MESSAGE_HINT;

                            $messages_controller->addRecipient($moderator_id);

                            $messages_controller->sendNoticePM(array('content' => nl2br($messages)));

                            $messages_controller->clearRecipients();
                        }
                    } else {
                        $to = array('email' => $this->options['email'], 'name' => $this->cms_config->sitename . ' FeedBack');
                    }

                    if (isset($items['file'])) {

                        $file_url = $this->parsefile($items['file'], true);

                        $file = is_array($items['file']) ? $items['file'] : cmsModel::yamlToArray($items['file']);
                    }

                    $letter = array('name' => 'feedback_new');

                    $replyto = array('email' => $items['email'], 'name' => $items['name']);

                    $this->sendEmailFeedback($replyto, $to, $letter, array(
                        'feedback_id' => $feedback_id,
                        'nickname' => $to['name'],
                        'user_name' => $items['user_name'],
                        'name' => $items['name'],
                        'e-mail' => $items['email'],
                        'title' => $items['title'],
                        'message' => $items['message'],
                        'date' => $items['date'],
                        'file' => isset($file_url) ? $file_url : '',
                        'file_path' => isset($file['path']) ? $file['path'] : ''
                    ));
//отправлять пользователю письмо с уведомлением об отправке
                    if ($this->options['notif'] == True) {

                        $letter = array('name' => 'feedbackl_notif');

                        $replyto = array('email' => $this->cms_config->mail_from, 'name' => $this->cms_config->sitename);

                        $this->sendEmailFeedback($replyto, $items['email'], $letter, array(
                            'name' => $items['name'],
                            'e-mail' => $items['email'],
                            'title' => $items['title'],
                            'message' => $items['message'],
                            'date' => $items['date'],
                            'file' => isset($file_url) ? $file_url : '',
                            'file_path' => isset($file['path']) ? $file['path'] : ''
                        ));
                    }

                    cmsUser::addSessionMessage(LANG_FEEDBACKL_OK_MESSAGE, 'info');

                    switch ($this->options['rederect']) {

                        case 0:

                            $this->redirectTo('feedbackl');

                        case 1:

                            $sess_id = rand(100, 10000);

                            cmsUser::sessionSet('feedbackl' . $sess_id, $items);

                            $this->redirectTo('feedbackl', false, false, array('s' => $sess_id));

                        case 2:

                            $this->redirect($this->options['rederect_url']);
                    }
                }
            }
            if ($errors && $is_captcha_valid) {

                cmsUser::addSessionMessage(LANG_FORM_ERRORS, 'error');
            }
            if (!$user->id) {

                $captcha_html = cmsEventsManager::hook('captcha_html');
            }
            return $this->cms_template->render('feedbackl', array(
                        'form' => $form,
                        'captcha_html' => isset($captcha_html) ? $captcha_html : false,
                        'errors' => isset($errors) ? $errors : false,
                        'items' => isset($items) ? $items : false
            ));
        }
    }

}
